# ngo

ngo is a program and python library to optimize non ground logic ASP encodings for performance.
Please read [the documentation](https://potassco.org/ngo/).

You can get more information about [contributing](CONTRIBUTING.md) and [development](DEVELOPMENT.md).
